@@ -27,6 +27,9 @@ from collections import namedtuple
 
 Entry = namedtuple('Entry', 'header sequence')
 
+class FastaError(ValueError):
+    pass
+
 class FastaFile(file):
     """ FASTA file.
     The default iterator will go through the entries in the file (not the rows). 
@@ -97,7 +100,7 @@ def read_fasta(stream):
             sequence.append(row)
     sequence = ''.join(sequence)
     if header is None:
-        raise RuntimeError('Missng FASTA header.')
+        raise RuntimeError('Missing FASTA header.')
     yield Entry(header, sequence)
 
 EntryBin = namedtuple('Entry', 'header sequence bits')
